=== added directory 'dbus'
=== added file 'dbus/landscape.conf'
--- dbus/landscape.conf	1970-01-01 00:00:00 +0000
+++ dbus/landscape.conf	2010-06-10 13:30:58 +0000
@@ -0,0 +1,62 @@
+<!DOCTYPE busconfig PUBLIC
+ "-//freedesktop//DTD D-BUS Bus Configuration 1.0//EN"
+ "http://www.freedesktop.org/standards/dbus/1.0/busconfig.dtd">
+<busconfig>
+
+  <policy user="landscape">
+    <allow own="com.canonical.landscape.Broker" />
+    <allow own="com.canonical.landscape.Monitor" />
+
+    <allow send_destination="com.canonical.landscape.Broker" />
+    <allow receive_sender="com.canonical.landscape.Broker" />
+
+    <allow send_destination="com.canonical.landscape.Monitor" />
+    <allow receive_sender="com.canonical.landscape.Monitor" />
+
+    <allow send_destination="com.canonical.landscape.Manager" />
+    <allow receive_sender="com.canonical.landscape.Manager" />
+
+    <allow send_interface="org.freedesktop.Hal.Manager" />
+    <allow send_interface="org.freedesktop.Hal.Device" />
+
+  </policy>
+
+  <!-- this is a horrible hack -->
+  <policy user="haldaemon">
+
+    <allow receive_sender="com.canonical.landscape.Manager" />
+    <allow receive_sender="com.canonical.landscape.Monitor" />
+    <allow receive_sender="com.canonical.landscape.Broker" />
+
+  </policy>
+
+  <policy user="root">
+    <allow own="com.canonical.landscape.Manager" />
+
+    <allow send_destination="com.canonical.landscape.Broker" />
+    <allow receive_sender="com.canonical.landscape.Broker" />
+
+    <allow send_destination="com.canonical.landscape.Monitor" />
+    <allow receive_sender="com.canonical.landscape.Monitor" />
+
+    <allow send_destination="com.canonical.landscape.Manager" />
+    <allow receive_sender="com.canonical.landscape.Manager" />
+  </policy>
+
+  <policy context="default">
+    <deny own="com.canonical.landscape.Broker" />
+    <deny own="com.canonical.landscape.Monitor" />
+    <deny own="com.canonical.landscape.Manager" />
+
+    <deny send_destination="com.canonical.landscape.Broker" />
+    <deny receive_sender="com.canonical.landscape.Broker" />
+
+    <deny send_destination="com.canonical.landscape.Monitor" />
+    <deny receive_sender="com.canonical.landscape.Monitor" />
+
+    <deny send_destination="com.canonical.landscape.Manager" />
+    <deny receive_sender="com.canonical.landscape.Manager" />
+
+  </policy>
+
+</busconfig>

=== modified file 'debian/landscape-client.install'
--- debian/landscape-client.install	2010-05-11 08:02:29 +0000
+++ debian/landscape-client.install	2010-06-10 13:30:58 +0000
@@ -8,5 +8,7 @@
 usr/bin/landscape-package-reporter
 usr/bin/landscape-release-upgrader
 usr/bin/landscape-is-cloud-managed
+usr/bin/landscape-dbus-proxy
 usr/share/landscape/cloud-default.conf
+etc/dbus-1/system.d/landscape.conf
 usr/lib/landscape

=== modified file 'debian/landscape-client.postinst'
--- debian/landscape-client.postinst	2010-05-11 08:02:29 +0000
+++ debian/landscape-client.postinst	2010-06-10 13:30:58 +0000
@@ -89,8 +89,13 @@
             rm $very_old_cron_job
         fi
 
-        # Remove obsolete D-Bus configuration file
-        rm -f /etc/dbus-1/system.d/landscape.conf
+        # Check if we're upgrading from a D-Bus version
+        if ! [ -z $2 ]; then
+            if dpkg --compare-versions $2 lt 1.5.1; then
+                start-stop-daemon -x /usr/bin/landscape-dbus-proxy -b -c landscape -u landscape -S
+             fi
+         fi
+
     ;;
 
     abort-upgrade|abort-remove|abort-deconfigure)

=== modified file 'debian/rules'
--- debian/rules	2010-05-11 08:02:29 +0000
+++ debian/rules	2010-06-10 13:30:58 +0000
@@ -54,6 +54,7 @@
 	install -D -o root -g root -m 755 debian/landscape-sysinfo.wrapper $(root_dir)/usr/share/landscape/landscape-sysinfo.wrapper
 	install -D -o root -g root -m 644 debian/cloud-default.conf $(root_dir)/usr/share/landscape/cloud-default.conf
 	install -D -o root -g root -m 755 smart-update/smart-update $(root_dir)/usr/lib/landscape/smart-update
+	install -D -o root -g root -m 644 dbus/landscape.conf $(root_dir)/etc/dbus-1/system.d/landscape.conf
 
 binary-indep:
 # do nothing

=== added file 'scripts/landscape-dbus-proxy'
--- scripts/landscape-dbus-proxy	1970-01-01 00:00:00 +0000
+++ scripts/landscape-dbus-proxy	2010-06-10 13:30:58 +0000
@@ -0,0 +1,76 @@
+#!/usr/bin/env python
+
+import os
+import dbus
+import dbus.service
+import dbus.glib # This as side effects, don't remove it!
+
+from dbus.service import Object, BusName, method
+
+from twisted.internet import glib2reactor
+glib2reactor.install()
+from twisted.internet import reactor
+
+from landscape.lib.bpickle import loads
+from landscape.lib.lock import lock_path, LockError
+from landscape.reactor import TwistedReactor
+from landscape.deployment import Configuration
+from landscape.broker.amp import RemoteBrokerConnector
+
+
+BUS_NAME = "com.canonical.landscape.Broker"
+OBJECT_PATH = "/com/canonical/landscape/Broker"
+
+
+def array_to_string(array):
+    """Convert an L{Array} of L{Byte}s (or integers) to a Python str."""
+    result = []
+    for item in array:
+        if item < 0:
+            item = item + 256
+        result.append(chr(item))
+    return "".join(result)
+
+
+class BrokerDBusObject(Object):
+    """A DBus-published object proxing L{RemoteBroker.send_message}.
+
+    It is used when upgrading from a DBus-based version of the Landscape client
+    to the newer AMP-based one, for letting the old package-changer process
+    performing the upgrade communicate with the new version of the client.
+    """
+
+    bus_name = BUS_NAME
+    object_path = OBJECT_PATH
+
+    def __init__(self, config):
+        super(BrokerDBusObject, self).__init__(BusName(
+            self.bus_name, dbus.SystemBus()), object_path=self.object_path)
+        self.config = config
+
+    @method(BUS_NAME)
+    def send_message(self, message, urgent=True):
+        """Queue the given message in the message exchange."""
+        message = loads(array_to_string(message))
+
+        def cb_connected(broker):
+            result = broker.send_message(message, urgent=True)
+            return result.addCallback(cb_done)
+
+        def cb_done(ignored):
+            return reactor.stop()
+
+        twisted_reactor = TwistedReactor()
+        connector = RemoteBrokerConnector(twisted_reactor, self.config)
+        connected = connector.connect()
+        connected.addCallback(cb_connected)
+
+
+config = Configuration()
+lock_filename = os.path.join(config.data_path, "package", "changer.lock")
+try:
+    lock_path(lock_filename)
+except LockError:
+    # The package-changer is running, let's try to help it
+    remote = BrokerDBusObject(config)
+    reactor.run()

=== modified file 'setup.py'
--- setup.py	2009-10-27 12:45:38 +0000
+++ setup.py	2010-06-10 13:30:58 +0000
@@ -29,7 +29,8 @@
                "scripts/landscape-package-reporter",
                "scripts/landscape-release-upgrader",
                "scripts/landscape-sysinfo",
-               "scripts/landscape-is-cloud-managed"],
+               "scripts/landscape-is-cloud-managed",
+               "scripts/landscape-dbus-proxy"],
       ext_modules=[Extension("landscape.lib.initgroups",
                              ["landscape/lib/initgroups.c"])]
      )

